=============================
Django Handy
=============================

.. image:: https://badge.fury.io/py/django-handy.svg
    :target: https://badge.fury.io/py/django-handy

.. image:: https://travis-ci.org/alextatarinov/django-handy.svg?branch=master
    :target: https://travis-ci.org/alextatarinov/django-handy

.. image:: https://codecov.io/gh/alextatarinov/django-handy/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/alextatarinov/django-handy

Set of handy helpers for developing Django web applications.

Quickstart
----------

Install Django Handy::

    pip install django-handy

Add it to your `INSTALLED_APPS`:

.. code-block:: python

    INSTALLED_APPS = (
        ...
        'django_handy',
        ...
    )

Features
--------

* TODO
